@@ -6,6 +6,7 @@ import time
 from collections import deque, namedtuple
 
 from ..hioing import ValidationError, VersionError
+from .. import hioing
 from .basing import State
 from . import tyming
 from ..core.tcp import serving, clienting
@@ -98,7 +99,7 @@ class Doist(tyming.Tymist):
 
             if retyme <= self.tyme:  # run it now
                 try:
-                    tock = dog.send(None)  #  nothing to send for now
+                    tock = dog.send(self.tyme)  #  nothing to send for now
                     dogs.append((dog, retyme + tock))  # reappend for next pass
                     # allows for tock change during run
                 except StopIteration:  # returned instead of yielded
@@ -143,7 +144,7 @@ class Doist(tyming.Tymist):
 
                     if self.real:  # wait for real time to expire
                         while not self.timer.expired:
-                            time.sleep(self.timer.remaining)
+                            time.sleep(max(0.0, self.timer.remaining))
                         self.timer.restart()  #  no time lost
 
                     if self.limit and tymer.expired:
@@ -183,13 +184,13 @@ class Doer(tyming.Tymee):
     Doer is generator creator and has extra methods and attributes that plain
     generator function does not
 
-    Attributes:
+    Inherited Attributes:
 
     Inherited Properties:
         .tyme is float relative cycle time, .tyme is artificial time
 
     Attributes:
-        .tymist is Tymist instance that provides relative cycle time as .tymist.tyme
+
 
     Properties:
         .tock is desired time in seconds between runs or until next run,
@@ -205,17 +206,18 @@ class Doer(tyming.Tymee):
 
     """
 
-    def __init__(self, tymist=None, tock=0.0):
+    def __init__(self, tock=0.0, **kwa):
         """
         Initialize instance.
+
+        Inherited Parameters:
+            tymist is  Tymist instance
+
         Parameters:
-           tymist is Tymist instance
            tock is float seconds initial value of .tock
 
         """
-        if tymist is None:
-            tymist = tyming.Tymist(tyme=0.0)
-        super(Doer, self).__init__(tymist=tymist)
+        super(Doer, self).__init__(**kwa)
         self.tock = tock  # desired tyme interval between runs, 0.0 means asap
 
 
@@ -256,9 +258,12 @@ class Doer(tyming.Tymee):
         """
         try:
             # enter context
+            self.wind(tymist)  # change tymist and dependencies
+            self.tock = tock
+            tyme = self.tyme
 
             while (True):  # recur context
-                feed = (yield (tock))  # yields tock then waits for next send
+                tyme = (yield (tock))  # yields tock then waits for next send
 
 
         except GeneratorExit:  # close context, forced exit due to .close
@@ -446,32 +451,33 @@ class WhoDoer(Doer):
         Generator method to run this doer, class based generator
         Calling this method returns generator
         """
-        feed = "_"
-        count = 0
-
         try:
             # enter context
+            count = 0
+            self.wind(tymist)  # change tymist and dependencies
+            self.tock = tock
+            tyme = self.tyme
 
-            self.states.append(State(tyme=tymist.tyme, context="enter", feed=feed, count=count))
+            self.states.append(State(tyme=tymist.tyme, context="enter", feed=tyme, count=count))
             while (True):  # recur context
-                feed = (yield (tock))  # yields tock then waits for next send
+                tyme = (yield (tock))  # yields tock then waits for next send
                 count += 1
-                self.states.append(State(tyme=tymist.tyme, context="recur", feed=feed, count=count))
+                self.states.append(State(tyme=tymist.tyme, context="recur", feed=tyme, count=count))
                 if count > 3:
                     break  # normal exit
 
         except GeneratorExit:  # close context, forced exit due to .close
             count += 1
-            self.states.append(State(tyme=tymist.tyme, context='close', feed=feed, count=count))
+            self.states.append(State(tyme=tymist.tyme, context='close', feed=tyme, count=count))
 
         except Exception:  # abort context, forced exit due to uncaught exception
             count += 1
-            self.states.append(State(tyme=tymist.tyme, context='abort', feed=feed, count=count))
+            self.states.append(State(tyme=tymist.tyme, context='abort', feed=tyme, count=count))
             raise
 
         finally:  # exit context,  unforced exit due to normal exit of try
             count += 1
-            self.states.append(State(tyme=tymist.tyme, context='exit', feed=feed, count=count))
+            self.states.append(State(tyme=tymist.tyme, context='exit', feed=tyme, count=count))
 
         return (True)  # return value of yield from, or yield ex.value of StopIteration
 
@@ -548,7 +554,17 @@ class ServerDoer(Doer):
         self.server = server
 
 
-    def do(self, tymist, tock=None):
+    def wind(self, tymist):
+        """
+        Inject new ._tymist and any other bundled tymee references
+        Update any dependencies on a change in ._tymist:
+            starts over itself at new ._tymists time
+        """
+        super(ServerDoer, self).wind(tymist)
+        self.server.tymist = self._tymist
+
+
+    def do(self, tymist, tock=0.0):
         """
         Generator method to run this doer, class based generator
         Calling this method returns generator
@@ -558,10 +574,13 @@ class ServerDoer(Doer):
 
         try:
             # enter context
+            self.wind(tymist)
+            self.tock = tock
+            tyme = self.tyme
             self.server.reopen()  #  opens accept socket
 
             while (True):  # recur context
-                feed = (yield (tock))  # yields tock then waits for next send
+                tyme = (yield (tock))  # yields tock then waits for next send
                 self.server.serviceAll()
 
         except GeneratorExit:  # close context, forced exit due to .close
@@ -573,7 +592,7 @@ class ServerDoer(Doer):
         finally:  # exit context,  unforced exit due to normal exit of try
             self.server.close()
 
-        return
+        return True
 
 
 class EchoServerDoer(ServerDoer):
@@ -598,7 +617,7 @@ class EchoServerDoer(ServerDoer):
 
     """
 
-    def do(self, tymist, tock=None):
+    def do(self, tymist, tock=0.0):
         """
         Generator method to run this doer, class based generator
         Calling this method returns generator
@@ -609,10 +628,13 @@ class EchoServerDoer(ServerDoer):
 
         try:
             # enter context
+            self.wind(tymist)
+            self.tock = tock
+            tyme = self.tyme
             self.server.reopen()  #  opens accept socket
 
             while (True):  # recur context
-                feed = (yield (tock))  # yields tock then waits for next send
+                tyme = (yield (tock))  # yields tock then waits for next send
                 self.server.serviceAll()
 
                 for ca, ix in self.server.ixes.items():  # echo back
@@ -629,7 +651,7 @@ class EchoServerDoer(ServerDoer):
         finally:  # exit context,  unforced exit due to normal exit of try
             self.server.close()
 
-        return
+        return True
 
 
 class ClientDoer(Doer):
@@ -670,7 +692,17 @@ class ClientDoer(Doer):
         self.client = client
 
 
-    def do(self, tymist, tock=None):
+    def wind(self, tymist):
+        """
+        Inject new ._tymist and any other bundled tymee references
+        Update any dependencies on a change in ._tymist:
+            starts over itself at new ._tymists time
+        """
+        super(ClientDoer, self).wind(tymist)
+        self.client.tymist = self._tymist
+
+
+    def do(self, tymist, tock=0.0):
         """
         Generator method to run this doer, class based generator
         Calling this method returns generator
@@ -680,10 +712,13 @@ class ClientDoer(Doer):
 
         try:
             # enter context
+            self.wind(tymist)
+            self.tock = tock
+            tyme = self.tyme
             self.client.reopen()  #  opens accept socket
 
             while (True):  # recur context
-                feed = (yield (tock))  # yields tock then waits for next send
+                tyme = (yield (tock))  # yields tock then waits for next send
                 self.client.serviceAll()
 
         except GeneratorExit:  # close context, forced exit due to .close
@@ -695,5 +730,5 @@ class ClientDoer(Doer):
         finally:  # exit context,  unforced exit due to normal exit of try
             self.client.close()
 
-        return
+        return True
 
